@@ -199,6 +199,141 @@ def operator_check(left_argument, right_argument, show_failed=False, print_width
         return returned_dictionary
 
 
+def argument_inspector(arg, no_of_arguments, p=False, print_width=120):
+    from collections import defaultdict
+    rtrnd_dct = defaultdict(set)
+    if no_of_arguments >= 0:
+        try:
+            x = eval(f'{arg}()')
+            rtrnd_dct[0].add(True)
+        except:
+            pass
+
+    if no_of_arguments >= 1:
+        import enhanced_dir
+        for i in enhanced_dir.extended_builtins + inspection_arguments:
+            try:
+                x = eval(f'{arg}({i})')
+                rtrnd_dct[1].add(i)
+            except:
+                pass
+
+            try:
+                x = eval(f'{arg}({i}())')
+                rtrnd_dct[1].add(i)
+            except:
+                pass
+
+    if no_of_arguments >= 2:
+        for i in enhanced_dir.extended_builtins + inspection_arguments:
+            for j in enhanced_dir.extended_builtins + inspection_arguments:
+                try:
+                    x = eval(f'{arg}({i}, {j})')
+                    rtrnd_dct[2].add((i, j))
+                except:
+                    pass
+
+                try:
+                    x = eval(f'{arg}({i}(), {j}())')
+                    rtrnd_dct[2].add((f'{i}()', f'{j}()'))
+                except:
+                    pass
+
+                try:
+                    x = eval(f'{arg}({i}(), {j})')
+                    rtrnd_dct[2].add((f'{i}()', j))
+                except:
+                    pass
+
+                try:
+                    x = eval(f'{arg}({i}, {j}())')
+                    rtrnd_dct[2].add((i, f'{j}()'))
+                except:
+                    pass
+
+                # try:
+                #   x = eval(f'{arg}({i!r}, {j!r})')
+                #   rtrnd_dct[2].add((i, j))
+                # except:
+                #   pass
+
+                # try:
+                #   x = eval(f'{arg}({i!r}(), {j!r}())')
+                #   rtrnd_dct[2].add((f'{i}()', f'{j}()'))
+                # except:
+                #   pass
+
+                # try:
+                #   x = eval(f'{arg}({i!r}(), {j!r})')
+                #   rtrnd_dct[2].add((f'{i}()', j))
+                # except:
+                #   pass
+
+                # try:
+                #   x = eval(f'{arg}({i!r}, {j!r}())')
+                #   rtrnd_dct[2].add((i, f'{j}()'))
+                # except:
+                #   pass
+
+    if no_of_arguments >= 3:
+        for i in enhanced_dir.extended_builtins + inspection_arguments:
+            for j in enhanced_dir.extended_builtins + inspection_arguments:
+                for k in enhanced_dir.extended_builtins + inspection_arguments:
+                    try:
+                        x = eval(f'{arg}({i}, {j}, {k})')
+                        rtrnd_dct[3].add((i, j, k))
+                    except:
+                        pass
+
+                    try:
+                        x = eval(f'{arg}({i}, {j}, {k}())')
+                        rtrnd_dct[3].add((i, j, f'{k}()'))
+                    except:
+                        pass
+
+                    try:
+                        x = eval(f'{arg}({i}, {j}(), {k})')
+                        rtrnd_dct[3].add((i, f'{j}()', k))
+                    except:
+                        pass
+
+                    try:
+                        x = eval(f'{arg}({i}, {j}(), {k}())')
+                        rtrnd_dct[3].add((i, f'{j}()', f'{k}()'))
+                    except:
+                        pass
+
+                    try:
+                        x = eval(f'{arg}({i}(), {j}, {k})')
+                        rtrnd_dct[3].add((f'{i}()', j, k))
+                    except:
+                        pass
+
+                    try:
+                        x = eval(f'{arg}({i}(), {j}, {k}())')
+                        rtrnd_dct[3].add((f'{i}()', j, f'{k}()'))
+                    except:
+                        pass
+
+                    try:
+                        x = eval(f'{arg}({i}(), {j}(), {k})')
+                        rtrnd_dct[3].add((f'{i}()', f'{j}()', k))
+                    except:
+                        pass
+
+                    try:
+                        x = eval(f'{arg}({i}(), {j}(), {k}())')
+                        rtrnd_dct[3].add((f'{i}()', f'{j}()', f'{k}()'))
+                    except:
+                        pass
+
+    if p:
+        from pprint import pprint
+        pprint(rtrnd_dct, compact=True, width=print_width)
+    else:
+        return rtrnd_dct
+
+
 extended_builtins = ['Ellipsis', 'False', 'None', 'NotImplemented', 'True', 'abs', 'all', 'any',
                      'ascii', 'bin', 'bool', 'bytearray', 'bytes', 'callable', 'chr',
                      'classmethod', 'compile', 'complex', 'delattr', 'dict',
@@ -222,3 +357,7 @@ external_checks = {'imports': 'from collections import Counter, namedtuple, defa
                                from decimal import Decimal;',
                    'modules': ['Counter', 'Fraction', 'Decimal', 'defaultdict', 'OrderedDict', 'namedtuple',
                                'SimpleNamespace']}
+
+inspection_arguments = [1, 1.2, 'abc', '1', '1.2', '1/2', {1, 2, 3}, {'a': 1, 'b': 2}, (1, 2, 3), [1, 2, 3],
+                        {'a', 'b', 'c'}, ('a', 'b', 'c'), ['a', 'b', 'c'], 1 + 2j, b'2', b'a', bytearray(1),
+                        frozenset({1, 2, 3}), frozenset({'a', 'b', 'c'})]
